//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// June 2000
//
#ifndef TIMEORDEREDTABLE_H
#define TIMEORDEREDTABLE_H

#include <Dal.h>
#include <STime.h>
#include <string>
#include <vector>
#include <utility>

//
// A DAL table sorted in time ascending order.
//
// lower_bound returns the first row where time(row) >= t, or
// tab->rows() if such row does not exist. It is always row > 0,
// as we want t to be contained in the time range available.
//
// upper_bound returns the last row where time(row) >= t, or
// tab->rows() if such row does not exist. It is always row > 0,
// as we want t to be contained in the time range available.
//

class TimeOrderedTable {
 public:
  TimeOrderedTable(const Table *tab, const string& timename = "TIME");
  ~TimeOrderedTable();
  const Table& table() const;
  unsigned rows() const;
  unsigned validTimes() const;
  unsigned lower_bound(const STime& t) const;
  unsigned upper_bound(const STime& t) const;
  unsigned last_less_than(const STime& t) const;
  unsigned first_less_than(const STime& t) const;
  const STime& time_of_row(const unsigned row) const;
  const STime& first_time() const;
  const STime& last_time() const;
  bool row_has_time(const unsigned row) const;

 private:

  const Table *_tab;
  vector<pair<STime, unsigned> > _stimes;
  ColumnData *_col;

  typedef vector<pair<STime, unsigned> >::const_iterator CI;

};

#endif
